# Jira Service Management Integration
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/jira-service-management-integration#overview)
  * [Benefits](https://help.sap.com/docs/leanix/ea/jira-service-management-integration#benefits)
  * [Scope](https://help.sap.com/docs/leanix/ea/jira-service-management-integration#scope)
  * [Limitations](https://help.sap.com/docs/leanix/ea/jira-service-management-integration#limitations)
  * [Synchronizing Data](https://help.sap.com/docs/leanix/ea/jira-service-management-integration#synchronizing-data)
  * [Next Steps](https://help.sap.com/docs/leanix/ea/jira-service-management-integration#next-steps)
  * [Related Information](https://help.sap.com/docs/leanix/ea/jira-service-management-integration#related-information)


Use the Jira Service Management integration to synchronize IT asset and application data between your configuration management database (CMDB) and SAP LeanIX.
